@@ -4,8 +4,6 @@
 /**
  *  @file   OS_NS_Thread.h
  *
- *  $Id: OS_NS_Thread.h 97208 2013-06-26 10:28:22Z johnnyw $
- *
  *  @author Douglas C. Schmidt <schmidt@cs.wustl.edu>
  *  @author Jesper S. M|ller<stophph@diku.dk>
  *  @author and a cast of thousands...
@@ -38,6 +36,12 @@
 # include "ace/ACE_export.h"
 # include "ace/Object_Manager_Base.h"
 
+#if defined (ACE_HAS_TSS_EMULATION) && !defined (ACE_HAS_THREAD_SPECIFIC_STORAGE)
+# if defined (ACE_HAS_VXTHREADS) && !defined (_WRS_CONFIG_SMP) && !defined (INCLUDE_AMP_CPU)
+#  include "taskVarLib.h" /* used by VxWorks < 6.9 */
+# endif /* VxWorks and ! SMP */
+#endif
+
 # if defined (ACE_EXPORT_MACRO)
 #   undef ACE_EXPORT_MACRO
 # endif
@@ -156,6 +160,7 @@ ACE_END_VERSIONED_NAMESPACE_DECL
 
 #   elif defined (ACE_VXWORKS)
 #     include /**/ <sysLib.h> // for sysClkRateGet()
+#     include /**/ <types/vxTypes.h>
 #     if !defined (__RTP__)
 #       include /**/ <taskLib.h>
 #       include /**/ <taskHookLib.h>
@@ -224,8 +229,8 @@ typedef struct
   char *name_;
 } ACE_sema_t;
 #     endif /* !ACE_HAS_POSIX_SEM */
-typedef int ACE_thread_t;
-typedef int ACE_hthread_t;
+typedef ACE_VX_TASK_ID ACE_thread_t;
+typedef ACE_VX_TASK_ID ACE_hthread_t;
 // Key type: the ACE TSS emulation requires the key type be unsigned,
 // for efficiency.  (Current POSIX and Solaris TSS implementations also
 // use u_int, so the ACE TSS emulation is compatible with them.)
@@ -875,6 +880,15 @@ private:
 #   else  /* ! ACE_HAS_THREAD_SPECIFIC_STORAGE */
   /// Location of current thread's TSS array.
   static void **&tss_base ();
+
+#     if defined (ACE_HAS_VXTHREADS)
+#       if (defined (_WRS_CONFIG_SMP) || defined (INCLUDE_AMP_CPU))
+  static __thread void* ace_tss_keys;
+#       else  /* ! VxWorks SMP */
+  static void* ace_tss_keys;
+#       endif /* ! VxWorks SMP */
+#     endif /* ACE_HAS_VXTHREADS */
+
 #   endif /* ! ACE_HAS_THREAD_SPECIFIC_STORAGE */
 
 #   if defined (ACE_HAS_THREAD_SPECIFIC_STORAGE)
